@@ -5,8 +5,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KLDAP_LDAPURL_H
-#define KLDAP_LDAPURL_H
+#pragma once
 
 #include <QStringList>
 
@@ -34,19 +33,19 @@ public:
      * A class holding the extension name and state whether
      * the extension is critical.
      */
-    typedef struct {
+    using Extension = struct {
         QString value;
         bool critical;
-    } Extension;
+    };
 
     /**
      * Describes the scope of the LDAP url.
      */
-    typedef enum {
+    using Scope = enum {
         Base, ///< Only the same level as the url.
         One, ///< The level of the url and the one below.
         Sub ///< All levels below the url's level.
-    } Scope;
+    };
 
     /**
      * Constructs an empty LDAP url.
@@ -163,8 +162,7 @@ public:
 
 private:
     class LdapUrlPrivate;
-    LdapUrlPrivate *const d;
+    std::unique_ptr<LdapUrlPrivate> const d;
 };
 }
 
-#endif
